@@ -355,8 +355,12 @@ def get_jobs(api, skip=None, limit=None, search=None, job_type=JOB_TYPE_PIG):
     :rtype: list:
     :returns: list of dict of job details
     """
-    return api.get('jobs',
-                   params={'skip': skip, 'limit': limit, 'job_type': job_type, 'search': search})
+    params = {'skip': skip, 'limit': limit, 'job_type': job_type}
+    if search:
+        for key, val in search.iteritems():
+            request_key = 'search[{}]'.format(key)
+            params[request_key] = val
+    return api.get('jobs', params=params)
 
 def block_until_job_complete(api, job_id, poll_frequency_sec=5.0):
     """
