@@ -27,6 +27,17 @@ class TestJobs(unittest.TestCase):
         self.project_name = 'my_project'
         self.script_name = 'my_script'
 
+    def test_get_script_name_key(self):
+        for job_type, expected_key in (
+            ('spark-on-jobserver', 'sparkclass'),
+            ('spark', 'sparkclass'),
+            ('luigi', 'luigiscript'),
+            ('pig', 'pigscript'),
+            ('unrecognized-type', 'pigscript'),
+        ):
+            expected_result = '{0}_name'.format(expected_key)
+            self.assertEqual(jobs.get_script_name_key(job_type), expected_result)
+
     def test_post_job_new_cluster(self):
         cluster_size = 2
         expected_job_id = 'abcdefghijklmnop'
